==> h2gis-1.4.0-sources.jar: org/h2gis/functions/spatial/properties/ST_ZMin.java <==
/**
 * H2GIS is a library that brings spatial support to the H2 Database Engine
 * <http://www.h2database.com>. H2GIS is developed by CNRS
 * <http://www.cnrs.fr/>.
 *
 * This code is part of the H2GIS project. H2GIS is free software; 
 * you can redistribute it and/or modify it under the terms of the GNU
 * Lesser General Public License as published by the Free Software Foundation;
 * version 3.0 of the License.
 *
 * H2GIS is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details <http://www.gnu.org/licenses/>.
 *
 *
 * For more information, please consult: <http://www.h2gis.org/>
 * or contact directly: info_at_h2gis.org
 */

package org.h2gis.functions.spatial.properties;

import com.vividsolutions.jts.geom.Geometry;
import org.h2gis.api.DeterministicScalarFunction;
import org.h2gis.utilities.jts_utils.CoordinateUtils;

/**
 * ST_ZMin returns the minimal z-value of the given geometry.
 *
 * @author Adam Gouge
 */
public class ST_ZMin extends DeterministicScalarFunction {

    public ST_ZMin() {
        addProperty(PROP_REMARKS, "Returns the minimal z-value of the given geometry.");
    }

    @Override
    public String getJavaStaticMethod() {
        return "getMinZ";
    }

    /**
     * Returns the minimal z-value of the given geometry.
     *
     * @param geom Geometry
     * @return The minimal z-value of the given geometry, or null if the geometry is null.
     */
    public static Double getMinZ(Geometry geom) {
        if (geom != null) {
            return CoordinateUtils.zMinMax(geom.getCoordinates())[0];
        } else {
            return null;
        }
    }
}

==> h2gis-1.5.0-sources.jar: org/h2gis/functions/spatial/properties/ST_ZMin.java <==
/**
 * H2GIS is a library that brings spatial support to the H2 Database Engine
 * <http://www.h2database.com>. H2GIS is developed by CNRS
 * <http://www.cnrs.fr/>.
 *
 * This code is part of the H2GIS project. H2GIS is free software; 
 * you can redistribute it and/or modify it under the terms of the GNU
 * Lesser General Public License as published by the Free Software Foundation;
 * version 3.0 of the License.
 *
 * H2GIS is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details <http://www.gnu.org/licenses/>.
 *
 *
 * For more information, please consult: <http://www.h2gis.org/>
 * or contact directly: info_at_h2gis.org
 */

package org.h2gis.functions.spatial.properties;

import org.h2gis.api.DeterministicScalarFunction;
import org.h2gis.utilities.jts_utils.CoordinateUtils;
import org.locationtech.jts.geom.Geometry;

/**
 * ST_ZMin returns the minimal z-value of the given geometry.
 *
 * @author Adam Gouge
 */
public class ST_ZMin extends DeterministicScalarFunction {

    public ST_ZMin() {
        addProperty(PROP_REMARKS, "Returns the minimal z-value of the given geometry.");
    }

    @Override
    public String getJavaStaticMethod() {
        return "getMinZ";
    }

    /**
     * Returns the minimal z-value of the given geometry.
     *
     * @param geom Geometry
     * @return The minimal z-value of the given geometry, or null if the geometry is null.
     */
    public static Double getMinZ(Geometry geom) {
        if (geom != null) {
            return CoordinateUtils.zMinMax(geom.getCoordinates())[0];
        } else {
            return null;
        }
    }
}
